@@ -1,5 +1,5 @@
 from .event import Event
-from .rule import RuleSet, Rule
+from .rule import RuleSet, Rule, BundleBy, MatchBy, BundleMinutes
 from .incident import Incident
 from .history import IncidentHistory
 from .ticket import Ticket, TicketNote
