@@ -4,7 +4,7 @@ import json
 from django.conf import settings
 
 
-def generate_signature(data, secret_key=settings.SECRET_KEY):
+def generate_signature(data, secret_key=None):
     """
     Generate an HMAC-SHA256 signature for the given data using the secret key.
 
@@ -12,6 +12,9 @@ def generate_signature(data, secret_key=settings.SECRET_KEY):
     :param secret_key: str or bytes - the shared secret key
     :return: str - the hex signature
     """
+    if secret_key is None:
+        from django.conf import settings
+        secret_key = settings.SECRET_KEY
     if isinstance(data, dict):
         data = json.dumps(data, separators=(',', ':'), sort_keys=True)
     if isinstance(data, str):
@@ -23,7 +26,7 @@ def generate_signature(data, secret_key=settings.SECRET_KEY):
     return signature
 
 
-def verify_signature(data, signature, secret_key=settings.SECRET_KEY):
+def verify_signature(data, signature, secret_key=None):
     """
     Verify an HMAC-SHA256 signature.
 
@@ -32,5 +35,8 @@ def verify_signature(data, signature, secret_key=settings.SECRET_KEY):
     :param secret_key: str or bytes - the shared secret key
     :return: bool - True if valid, False otherwise
     """
+    if secret_key is None:
+        from django.conf import settings
+        secret_key = settings.SECRET_KEY
     expected_signature = generate_signature(data, secret_key)
     return hmac.compare_digest(expected_signature, signature)
